@@ -77,6 +77,7 @@ class InstaBot:
         self.bot_start = datetime.datetime.now()
 
         # Time settings
+        self.start_day = datetime.datetime.today().day
         self.start_at_h = self.config.get('start_at_h')
         self.start_at_m = self.config.get('start_at_m')
         self.end_at_h = self.config.get('end_at_h')
@@ -750,28 +751,37 @@ class InstaBot:
             return True
 
     def loop_controller(self):
-        # 400 errors,
+        # 400 errors
         if self.error_400 >= self.error_400_to_ban:
-            self.logger.info(f"Bot receives {self.error_400} HTTP_400_Error(s), You're maybe banned! ")
-            self.logger.info(f"Pause for {self.ban_sleep_time} seconds")
+            self.logger.info(
+                f"Bot has received {self.error_400} HTTP_400_Error(s). It seems"
+                f" you're banned! Pause for {self.ban_sleep_time} seconds")
             time.sleep(self.generate_time(self.ban_sleep_time))
             self.error_400 = 0
 
         # exceed counters, program halt
-        if self.like_counter > self.like_per_run \
-                and self.follow_counter > self.follow_per_run \
-                and self.unfollow_counter > self.unfollow_per_run \
-                and self.comments_counter > self.comments_per_run:
-            self.prog_run = False
+        current_day = datetime.datetime.today().day
+        if self.start_day == current_day:
+            if self.like_counter > self.like_per_run \
+                    and self.unlike_counter > self.unlike_per_run \
+                    and self.follow_counter > self.follow_per_run \
+                    and self.unfollow_counter > self.unfollow_per_run \
+                    and self.comments_counter > self.comments_per_run:
+                self.prog_run = False
 
-        if self.iteration_ready('follow') or self.iteration_ready('unfollow') \
-                or self.iteration_ready('like') \
-                or self.iteration_ready('unlike') \
-                or self.iteration_ready('comments'):
-            return True
+            if self.iteration_ready('follow') \
+                    or self.iteration_ready('unfollow') \
+                    or self.iteration_ready('like') \
+                    or self.iteration_ready('unlike') \
+                    or self.iteration_ready('comments'):
+                return True
+            else:
+                time.sleep(1)
+                return False
         else:
-            time.sleep(1)
-            return False
+            self.start_day = current_day
+            self.like_counter, self.unlike_counter, self.follow_counter, \
+                self.unfollow_counter, self.comments_counter = 0, 0, 0, 0, 0
 
     def mainloop(self):
         medias = []
@@ -895,18 +905,26 @@ class InstaBot:
 
     def get_followers_count(self, username):
         url_info = self.url_user_detail % username
-        try:
-            resp = self.s.get(url_info)
+        resp = self.s.get(url_info)
+        if resp.status_code == 200:
             all_data = json.loads(
                 re.search("window._sharedData = (.*?);</script>", resp.text,
                           re.DOTALL).group(1))
             followers_count = all_data['entry_data']['ProfilePage'][0][
                 'graphql']['user']['edge_followed_by']['count']
-        except Exception as exc:
-            self.logger.warning(f"Could not retrieve number of followers of "
-                                f"user {username}, url: {url_info}. Status "
-                                f"code: {resp.status_code}")
+        elif resp.status_code == 429:
+            self.logger.critical(
+                f"Too many requests are sending to Instagram. It seems like a "
+                f"big numbers to actions like 'followers_per_run' are set in a "
+                f"configuration. Please wait for {resp.headers['retry-after']} "
+                f"seconds and only after that start the bot again")
+            exit(1)
+        else:
+            self.logger.warning(
+                f"Could not retrieve number of followers of user {username}, "
+                f"url: {url_info}. Status code: {resp.status_code}")
             followers_count = 0
+
         return followers_count
 
     def verify_account_name(self, username):
@@ -1189,7 +1207,7 @@ class InstaBot:
         action_counter_per_run = getattr(self, action + "_per_run", 0)
         registered_time = self.next_iteration.get(action, 0)
         return action_counter < action_counter_per_run \
-               and 0 <= registered_time < time.time()
+            and 0 <= registered_time < time.time()
 
     def generate_comment(self):
         c_list = list(itertools.product(*self.comment_list))
@@ -1211,19 +1229,23 @@ class InstaBot:
                 raw_data = re.search(
                     "window.__additionalDataLoaded\\('/p/[\\w-]+/',(.*?)\\);",
                     resp.text, re.DOTALL).group(1)
-                all_data = json.loads(raw_data)
+                all_data = json.loads(raw_data)['graphql']['shortcode_media']
 
-                if all_data['graphql']['shortcode_media']['owner']['id'] == \
-                        self.user_id:
+                if all_data['owner']['id'] == self.user_id:
                     self.logger.debug(f"This media {media_code}, url: "
                                       f"{url_check} is yours. Skipping it")
                     return False
 
-                edges = all_data['graphql']['shortcode_media'].get(
-                    'edge_media_to_comment', None)
+                if all_data['comments_disabled'] \
+                        or all_data['commenting_disabled_for_viewer']:
+                    self.logger.debug(
+                        f"Comments are disabled on this media {media_code}, "
+                        f"url: {url_check}. Skipping it")
+                    return False
+
+                edges = all_data.get('edge_media_to_comment', None)
                 if not edges:
-                    edges = all_data['graphql']['shortcode_media'].get(
-                        'edge_media_to_parent_comment', None)
+                    edges = all_data.get('edge_media_to_parent_comment', None)
 
                 comments = list(edges['edges'])
                 for comment in comments:
